==> pdfdownload-0.0.1.tar.gz: lib/pdfdownload.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:open_file/open_file.dart';
import 'package:path_provider/path_provider.dart';
import 'package:permission_handler/permission_handler.dart';

class DownloandPdf extends StatefulWidget {
  final bool isUseIcon;
  final String pdfUrl;
  final String fileNames;
  final Color color;
  final String titleDownload;
  final IconData icon;
  final double iconSize;
  final bool isDefaultTextStyle;
  final TextStyle textStyle;
  final Color loadingColor;
  DownloandPdf(
      {this.isUseIcon = false,
        @required this.pdfUrl,
        @required this.fileNames,
        this.color = Colors.blueGrey,
        this.titleDownload = 'Downlaod Here',
        this.icon = Icons.file_download,
        this.iconSize,
        this.isDefaultTextStyle = true,
        this.textStyle,
        this.loadingColor = Colors.grey});

  @override
  _DownloandPdfState createState() => _DownloandPdfState();
}

class _DownloandPdfState extends State<DownloandPdf> {
  Dio dio = Dio();
  bool isloadingfile = false;
  Directory directory;
  // function download pdf file
  Future<bool> savePdf(String url, String fileName) async {
    try {
      setState(() {
        isloadingfile = true;
      });
      if (Platform.isAndroid) {
        if (await _requestPermission(Permission.storage)) {
          directory = await getExternalStorageDirectory();
          String newPath = "";
          print(directory);
          List<String> paths = directory.path.split("/");
          for (int x = 1; x < paths.length; x++) {
            String folder = paths[x];
            if (folder != "Android") {
              newPath += "/" + folder;
            } else {
              break;
            }
          }
          newPath = newPath + "/Download";
          directory = Directory(newPath);
        } else {
          return false;
        }
      } else {
        if (await _requestPermission(Permission.storage)) {
          directory = await getTemporaryDirectory();
        } else {
          return false;
        }
      }

      if (!await directory.exists()) {
        await directory.create(recursive: true);
      }
      if (await directory.exists()) {
        File saveFile = File(directory.path + "/$fileName");
        await dio.download(
          url,
          saveFile.path,
          onReceiveProgress: (value1, value2) {
            print('Receve: ${value1.toStringAsFixed(0)}');
            print('Total: ${value2.toStringAsFixed(0)}');
          },
          options: Options(
            contentType: 'Content-Type',
          ),
        );
        if (Platform.isIOS) {}
        return true;
      }
    } catch (e) {
      print(e);
    } finally {
      setState(() {
        isloadingfile = false;
      });
      OpenFile.open(directory.path + "/$fileName");
    }
    return false;
  }

  Future<bool> _requestPermission(Permission permission) async {
    if (await permission.isGranted) {
      return true;
    } else {
      var result = await permission.request();
      if (result == PermissionStatus.granted) {
        return true;
      }
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    return isloadingfile == true
        ? Center(
        child: Text(
          'Loading...',
          style: TextStyle(color: widget.loadingColor),
        ))
        : Container(
      child: widget.isUseIcon
          ? GestureDetector(
          onTap: () async {
            await savePdf(widget.pdfUrl, widget.fileNames);
          },
          child: Icon(
            widget.icon,
            color: widget.color,
            size: widget.iconSize,
          ))
          : GestureDetector(
          onTap: () async {
            await savePdf(widget.pdfUrl, widget.fileNames);
          },
          child: Text(widget.titleDownload,
              style: widget.isDefaultTextStyle
                  ? TextStyle(
                  color: Theme.of(context).primaryColor,
                  decoration: TextDecoration.underline,
                  fontSize: 17.0)
                  : widget.textStyle)),
    );
  }
}

==> pdfdownload-0.0.2.tar.gz: lib/pdfdownload.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:open_file/open_file.dart';
import 'package:path_provider/path_provider.dart';
import 'package:permission_handler/permission_handler.dart';

class DownloandPdf extends StatefulWidget {
  final bool isUseIcon;
  final String? pdfUrl;
  final String? fileNames;
  final Color color;
  final String? titleDownload;
  final IconData icon;
  final double? iconSize;
  final bool isDefaultTextStyle;
  final TextStyle? textStyle;
  final Color loadingColor;
  DownloandPdf(
      {this.isUseIcon = false,
        @required this.pdfUrl,
        @required this.fileNames,
        this.color = Colors.blueGrey,
        this.titleDownload = 'Downlaod Here',
        this.icon = Icons.file_download,
        this.iconSize,
        this.isDefaultTextStyle = true,
        this.textStyle,
        this.loadingColor = Colors.grey});

  @override
  _DownloandPdfState createState() => _DownloandPdfState();
}

class _DownloandPdfState extends State<DownloandPdf> {
  Dio dio = Dio();
  bool isloadingfile = false;
  Directory? directory;
  // function download pdf file
  Future<bool> savePdf(String url, String fileName) async {
    try {
      setState(() {
        isloadingfile = true;
      });
      if (Platform.isAndroid) {
        if (await _requestPermission(Permission.storage)) {
          directory = await getExternalStorageDirectory();
          String newPath = "";
          print(directory);
          List<String> paths = directory!.path.split("/");
          for (int x = 1; x < paths.length; x++) {
            String folder = paths[x];
            if (folder != "Android") {
              newPath += "/" + folder;
            } else {
              break;
            }
          }
          newPath = newPath + "/Download";
          directory = Directory(newPath);
        } else {
          return false;
        }
      } else {
        if (await _requestPermission(Permission.storage)) {
          directory = await getTemporaryDirectory();
        } else {
          return false;
        }
      }

      if (!await directory!.exists()) {
        await directory!.create(recursive: true);
      }
      if (await directory!.exists()) {
        File saveFile = File(directory!.path + "/$fileName");
        await dio.download(
          url,
          saveFile.path,
          onReceiveProgress: (value1, value2) {
            print('Receve: ${value1.toStringAsFixed(0)}');
            print('Total: ${value2.toStringAsFixed(0)}');
          },
          options: Options(
            contentType: 'Content-Type',
          ),
        );
        if (Platform.isIOS) {}
        return true;
      }
    } catch (e) {
      print(e);
    } finally {
      setState(() {
        isloadingfile = false;
      });
      OpenFile.open(directory!.path + "/$fileName");
    }
    return false;
  }

  Future<bool> _requestPermission(Permission permission) async {
    if (await permission.isGranted) {
      return true;
    } else {
      var result = await permission.request();
      if (result == PermissionStatus.granted) {
        return true;
      }
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    return isloadingfile == true
        ? Center(
        child: Text(
          'Loading...',
          style: TextStyle(color: widget.loadingColor),
        ))
        : Container(
      child: widget.isUseIcon
          ? GestureDetector(
          onTap: () async {
            await savePdf('${widget.pdfUrl}', '${widget.fileNames}');
          },
          child: Icon(
            widget.icon,
            color: widget.color,
            size: widget.iconSize,
          ))
          : GestureDetector(
          onTap: () async {
            await savePdf('${widget.pdfUrl}', '${widget.fileNames}');
          },
          child: Text('${widget.titleDownload}',
              style: widget.isDefaultTextStyle
                  ? TextStyle(
                  color: Theme.of(context).primaryColor,
                  decoration: TextDecoration.underline,
                  fontSize: 17.0)
                  : widget.textStyle)),
    );
  }
}
